@@ -24,6 +24,7 @@ typedef unsigned char Bin;
 #include "ImagePGM.h"
 #include "ImageGray256.h"
 #include "ImageDouble.h"
+#include "MasqueBin.h"
 
 class ImageGray256;
 class ImageDouble;
@@ -38,26 +39,25 @@ class ImageBin{
 public :
 //	Constructeur
 	ImageBin (void);
-//	ImageGray256 (ImageBin *source);
-//	ImageGray256 (wxImage *ima, char *leurre);
-//	ImageBin (ImagePGM *source, wxString p_wNomLogique);
 	ImageBin (ImageGray256 *p_source, int p_iSeuil, wxString p_wNomLogique);
 	ImageBin (ImageDouble *p_source, double p_dSeuil, wxString p_wNomLogique);
 	ImageBin (ImageBin *source);
+	ImageBin (wxString p_wNomLogique, int p_iLargeur, int p_iHauteur);
 	~ImageBin (void);
 
 //	Optention d'information sur objet
 	int ChercherHauteur ();
 	int ChercherLargeur ();
-	wxString Chercher_Nom ();
+	wxString ChercherNom ();
 	Bin *ChercherImage ();
-
+	
 //	Methodes
 
 	wxBitmap * VisualiserBin ();
 	int Inverse ();
 	ImageBin *Diviser (wxString p_wNomDestination);
-
+	ImageBin *ErosionBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
+	ImageBin *DilatationBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
 };
 
 
