@@ -43,11 +43,13 @@ int g_NbImage256 = 0;
 int g_NbImageBin = 0;
 int g_NbImageDouble = 0;
 int g_NbMasqueDouble = 0;
-
+int g_NbMasqueBin = 0;
+// Type de l'Image affichee dans le canvas
+int g_iTypeImageAffiche = 0;
 
 // Liste Image Bin
 InterfaceImageBin g_InterfaceImageBin;
-wxMenu *g_wMenuImageBin;
+
 
 // Liste Image Gray
 InterfaceImageGray256 g_InterfaceImageGray256;
@@ -60,11 +62,10 @@ wxMenu *g_wMenuImageDouble;
 
 
 // Liste Masque Double
-WX_DECLARE_LIST(MasqueDouble, ListeMasqueDouble);
-#include <wx/listimpl.cpp>
-WX_DEFINE_LIST(ListeMasqueDouble)
+InterfaceMasqueDouble g_InterfaceMasqueDouble;
 
-ListeMasqueDouble g_wListeMasqueDouble(wxKEY_STRING);
+// Liste Masque Bin
+InterfaceMasqueBin g_InterfaceMasqueBin;
 
 // Indique qu'il peut y avoir plusieurs fenetres
 
@@ -96,6 +97,7 @@ bool MyApp::OnInit(void)
   // Creation de la fenetre principale
   // Create the main frame window
 
+
   wxString l_wNomFrame = wxString("TAI ") + wxString(LVERSION) + wxString("-Traitements et analyses  d'images");
   g_Frame = new MyFrame((wxFrame *) NULL, l_wNomFrame, wxPoint(0, 0), wxSize(600, 540));
 
@@ -120,7 +122,8 @@ bool MyApp::OnInit(void)
   wxMenu *l_wMenuOperationDouble = new wxMenu;
   wxMenu *l_wMenuAide = new wxMenu;
 
-  
+  wxMenu *g_wMenuImageBin = new wxMenu;
+  g_InterfaceImageBin.g_wMenuImageBin = g_wMenuImageBin;
   // Menu Fichier
   l_wMenuFichier -> Append(TAI_OUVRIR_FILE_256, "&Ouvrir-PGM", "Ouverture et chargement d'un fichier PGM");
   l_wMenuFichier -> Append(TAI_SAVE_FILE_256, "&Enregistrer-PGM", "Sauvegarde de l'image au format PGM");
@@ -135,6 +138,8 @@ bool MyApp::OnInit(void)
 
   // Menu Operation Bin
   l_wMenuOperationBin ->Append(TAI_INVERSER_BIN, "&Inverser", "Inversion de l'image binaire");
+l_wMenuOperationBin ->Append(TAI_EROSION_BIN, "&Erosion", "Erosion de l'image binaire");
+l_wMenuOperationBin ->Append(TAI_DILATATION_BIN, "&Dilatation", "Dilatation de l'image binaire");
 
   // Menu operation Double
   l_wMenuOperationDouble ->Append(TAI_CONVERTIR_IMAGE_GRAY, "&Convertir 256", "Conversion de l'image en 256 gris");
@@ -153,7 +158,7 @@ bool MyApp::OnInit(void)
   // Bar de Menu de l'application
   wxMenuBar *l_wMenuBar = new wxMenuBar;
 
-  l_wMenuBar -> Append(l_wMenuFichier, "&Fichier");
+  l_wMenuBar -> Append(l_wMenuFichier, _("&Fichier"));
   l_wMenuBar -> Append(g_InterfaceImageGray256.g_wMenuImage256, "&Image-256");
   l_wMenuBar -> Append(g_InterfaceImageBin.g_wMenuImageBin, "&Image-Bin");
   l_wMenuBar -> Append(g_InterfaceImageDouble.g_wMenuImageDouble, "&Image-Double");
@@ -197,13 +202,6 @@ bool MyApp::OnInit(void)
   wxString l_wNomMasqueLaplacien = wxString("Laplacien");
   wxString l_wCheminMasqueLaplacien = l_wRacine + wxString("/share/masque/laplacien.mf");
   
-  // Recherche si le masque Existe deja
-  if (g_wListeMasqueDouble.Find(l_wNomMasqueLaplacien)!=NULL)
-	{
-	(void)wxMessageBox("Masque Existant",
-            "Erreur", wxOK);
-	 return FALSE;
-	}
   // Creation du Filtre
   MasqueDouble * l_MasqueDoubleLaplacien = new MasqueDouble();
   l_iTest = l_MasqueDoubleLaplacien -> LectureFichier(l_wCheminMasqueLaplacien,
@@ -215,9 +213,8 @@ bool MyApp::OnInit(void)
             "Erreur", wxOK);
       return FALSE;
     }
+  g_InterfaceMasqueDouble.AjouterMasqueDouble(l_wNomMasqueLaplacien,l_MasqueDoubleLaplacien);
   
-  g_wListeMasqueDouble.Append(l_wNomMasqueLaplacien.GetData(),
-  l_MasqueDoubleLaplacien);
   g_NbMasqueDouble++;
   //////////////////
   // Chargement Moyen
@@ -233,17 +230,10 @@ bool MyApp::OnInit(void)
   wxString l_wNomMasqueMoyen = wxString("Moyen3x3");
   wxString l_wCheminMasqueMoyen = l_wRacine + wxString("/share/masque/moyen3x3.mf");
   
-  // Recherche si le masque Existe deja
-  if (g_wListeMasqueDouble.Find(l_wNomMasqueMoyen)!=NULL)
-	{
-	(void)wxMessageBox("Masque Existant",
-            "Erreur", wxOK);
-	 return FALSE;
-	}
+
   // Creation du Filtre
   MasqueDouble * l_MasqueDoubleMoyen = new MasqueDouble();
-  l_iTest = l_MasqueDoubleMoyen -> LectureFichier(l_wCheminMasqueMoyen,
-  l_wNomMasqueMoyen);
+  l_iTest = l_MasqueDoubleMoyen -> LectureFichier(l_wCheminMasqueMoyen, l_wNomMasqueMoyen);
   
   if (l_iTest != 1)
     {
@@ -252,10 +242,28 @@ bool MyApp::OnInit(void)
       return FALSE;
     }
   
-  g_wListeMasqueDouble.Append(l_wNomMasqueMoyen.GetData(),
-  l_MasqueDoubleMoyen);
+g_InterfaceMasqueDouble.AjouterMasqueDouble(l_wNomMasqueMoyen, l_MasqueDoubleMoyen);
   g_NbMasqueDouble++;
 
+  // Chargement d'un fichier masque bin
+  // Lecture Nom Logique du Masque bin
+  wxString l_wNomMasqueBin = wxString("NoyauBin");
+  wxString l_wCheminMasqueBin = l_wRacine + wxString("/share/masque/noyau.mb");
+  
+
+  // Creation du Masque
+  MasqueBin * l_MasqueBin = new MasqueBin();
+  l_iTest = l_MasqueBin -> LectureFichier(l_wCheminMasqueBin, l_wNomMasqueBin);
+  
+  if (l_iTest != 1)
+    {
+      (void)wxMessageBox("Erreur a l'ouverture",
+            "Erreur", wxOK);
+      return FALSE;
+    }
+  
+g_InterfaceMasqueBin.AjouterMasqueBin(l_wNomMasqueBin, l_MasqueBin);
+  g_NbMasqueBin++;
   return TRUE;
 }
 
@@ -310,6 +318,8 @@ BEGIN_EVENT_TABLE(MyFrame, wxFrame)
     
 // Menu operation-Bin
     EVT_MENU(TAI_INVERSER_BIN,   MyFrame::OnInverserBin)
+    EVT_MENU(TAI_EROSION_BIN,   MyFrame::OnErosionBin)
+    EVT_MENU(TAI_DILATATION_BIN,   MyFrame::OnDilatationBin)   
 
 // Menu Operation Double
     EVT_MENU(TAI_CONVERTIR_IMAGE_GRAY,   MyFrame::OnConvertirImageGray)
@@ -323,6 +333,7 @@ BEGIN_EVENT_TABLE(MyFrame, wxFrame)
     EVT_MENU(TAI_TEST,     MyFrame::OnTest)
 END_EVENT_TABLE()
 
+
 //-----------------------
 // Definition d'une frame
 //-----------------------
@@ -392,6 +403,7 @@ void MyFrame::OuvrirFile256(wxCommandEvent& WXUNUSED(event))
 }
 
 BEGIN_EVENT_TABLE(MyCanvas, wxScrolledWindow)
+    EVT_LEFT_DCLICK(MyCanvas::OnMouseLeft)
     EVT_PAINT(MyCanvas::OnPaint)
 END_EVENT_TABLE()
 
@@ -432,6 +444,18 @@ void MyCanvas::OnPaint(wxPaintEvent& WXUNUSED(event))
   }
 }
 
+void MyCanvas::OnMouseLeft(wxMouseEvent& event)
+{
+wxClientDC dc(this);
+PrepareDC(dc);
+wxPoint pos = event.GetPosition();
+long x = dc.DeviceToLogicalX( pos.x );
+long y = dc.DeviceToLogicalY( pos.y );
+wxString str;
+str.Printf( "position: %d,%d", (int)x, (int)y );
+g_Frame -> SetStatusText(str);
+}
+
 // ------------------------------------------
 // Define the behaviour for the frame closing
 // - must delete all frames except for the main one.
@@ -547,6 +571,28 @@ g_InterfaceImageBin.OnInverserBin();
 return;
 }
 
+//-----------------------
+// Erosion une image bin 
+//-----------------------
+
+void MyFrame::OnErosionBin(wxCommandEvent& WXUNUSED(event))
+{
+g_InterfaceImageBin.OnErosionBin();
+
+return;
+}
+
+//-----------------------
+// Erosion une image bin 
+//-----------------------
+
+void MyFrame::OnDilatationBin(wxCommandEvent& WXUNUSED(event))
+{
+g_InterfaceImageBin.OnDilatationBin();
+
+return;
+}
+
 //------------------------------------
 // Convolution Image Gray 256
 //------------------------------------
@@ -557,54 +603,23 @@ void MyFrame::OnConvoluer256(wxCommandEvent& event)
 ImageGray256
 	*l_pImageSourceGray256;
 
-int l_iNbMasque;
-l_iNbMasque = g_wListeMasqueDouble.Number();
-//l_iNbMasque = g_wListeMasqueDouble.GetCount();
-if (l_iNbMasque == 0)
-  {
-    wxMessageBox ("Il n'y a pas de masque", "Erreur", wxOK);
-    return;
-  }
-  
-// Affichage des masques disponibles
-
-l_iNbMasque = g_wListeMasqueDouble.Number();
-//l_iNbMasque = g_wListeMasqueDouble.GetCount();
-
-wxString l_wxNomMasque[l_iNbMasque];
-char * l_zChoix[l_iNbMasque];
-
-//wxNode *node = g_wListeMasqueDouble.First();
-wxNode *node = g_wListeMasqueDouble.First();
-int l_iIndice=0;
-while (node)
-  {
-    
-    l_wxNomMasque[l_iIndice] = ((MasqueDouble *)node->Data())->ChercherNom();
-    l_zChoix[l_iIndice] = (char *)l_wxNomMasque[l_iIndice].GetData();
-    l_iIndice++;
-    node = node->Next();
-  }
-
-wxString l_wxResultat = wxGetSingleChoice(wxString("Masque"), wxString("Nom"), l_iNbMasque, l_wxNomMasque,
-  NULL,  -1, -1, true, 200, 200);
-
-// si aucun choix fin
-
-if (l_wxResultat.IsEmpty())
-	{
-	(void)wxMessageBox("Pas de masque selectionne",
-            "Erreur", wxOK);
-	 return;
-	}
 
 // Recherche du masque selectionne
 MasqueDouble * l_MasqueDouble;
- l_MasqueDouble = g_wListeMasqueDouble.Find( l_wxResultat.GetData())->GetData();
+l_MasqueDouble = g_InterfaceMasqueDouble.SelectionMasqueDouble();
 
+if (l_MasqueDouble == NULL)
+	{
+	 return;
+	}
 // Lecture Nom Logique de L'image
 wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image source: ", "Nom de l'image", "");
 
+if (l_wNomImage.IsEmpty())
+	{
+	 return;
+	}
+	
 l_pImageSourceGray256 = g_InterfaceImageGray256.ChercherImageGray256(l_wNomImage);
 
 // Lecture Nom Logique de L'image
@@ -753,51 +768,15 @@ void MyFrame::OnConvoluerImageDouble(wxCommandEvent& event)
 
 ImageDouble
 	*l_pImageSourceDouble;
-
-int l_iNbMasque;
-l_iNbMasque = g_wListeMasqueDouble.Number();
-//l_iNbMasque = g_wListeMasqueDouble.GetCount();
-if (l_iNbMasque == 0)
-  {
-    wxMessageBox ("Il n'y a pas de masque", "Erreur", wxOK);
-    return;
-  }
-  
-// Affichage des masques disponibles
-
-l_iNbMasque = g_wListeMasqueDouble.Number();
-//l_iNbMasque = g_wListeMasqueDouble.GetCount();
-
-wxString l_wxNomMasque[l_iNbMasque];
-char * l_zChoix[l_iNbMasque];
-
-//wxNode *node = g_wListeMasqueDouble.First();
-wxNode *node = g_wListeMasqueDouble.First();
-int l_iIndice=0;
-while (node)
-  {
-    
-    l_wxNomMasque[l_iIndice] = ((MasqueDouble *)node->Data())->ChercherNom();
-    l_zChoix[l_iIndice] = (char *)l_wxNomMasque[l_iIndice].GetData();
-    l_iIndice++;
-    node = node->Next();
-  }
-
-wxString l_wxResultat = wxGetSingleChoice(wxString("Masque"), wxString("Nom"), l_iNbMasque, l_wxNomMasque,
-  NULL,  -1, -1, true, 200, 200);
-
-// si aucun choix fin
-
-if (l_wxResultat.IsEmpty())
-	{
-	(void)wxMessageBox("Pas de masque selectionne",
-            "Erreur", wxOK);
-	 return;
-	}
-
+	
 // Recherche du masque selectionne
 MasqueDouble * l_MasqueDouble;
- l_MasqueDouble = g_wListeMasqueDouble.Find( l_wxResultat.GetData())->GetData();
+l_MasqueDouble = g_InterfaceMasqueDouble.SelectionMasqueDouble();
+
+if (l_MasqueDouble == NULL)
+	{
+	 return;
+	}
 
 // Lecture Nom Logique de L'image
 wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image source: ", "Nom de l'image", "");
@@ -856,6 +835,7 @@ wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image source: ", "N
 
 l_pImageSourceDouble = g_InterfaceImageDouble.ChercherImageDouble(l_wNomImage);
 
+
 // Lecture Nom Logique de L'image
 wxString l_wNomImageDestination = wxGetTextFromUser("Entrez le nom de l'image destination: ", "Nom de l'image", "");
 
@@ -869,10 +849,12 @@ wxBeginBusyCursor();
 
 // Seuillage de l'Image - A faire verifier new
 ImageBin *l_ImageBinDestination = new ImageBin(l_pImageSourceDouble, l_dValeurSeuil, l_wNomImageDestination);
+//ImageBin *l_ImageBinDestination = new ImageBin();
 
 // Insertion dans la Liste
-
-g_InterfaceImageBin.AjouterImageBin(l_wNomImageDestination, l_ImageBinDestination); 
+printf("avant \n");
+g_InterfaceImageBin.AjouterImageBin(l_wNomImageDestination, l_ImageBinDestination);
+printf("apres \n");
 // Affichage
 
 if (g_Bitmap) //liberation de la memoire
@@ -917,14 +899,6 @@ if (l_wNomFichier.IsEmpty())
 // Lecture Nom Logique du Masque
 wxString l_wNomMasque = wxGetTextFromUser("Entrez le nom du masque", "Nom du masque", "");
 
-// Recherche si le masque Existe deja
-if (g_wListeMasqueDouble.Find(l_wNomMasque)!=NULL)
-	{	
-	(void)wxMessageBox("Masque Existant",
-            "Erreur", wxOK);
-	 return;
-	}
-
 // Creation du Filtre
 
 MasqueDouble * l_MasqueDouble = new MasqueDouble();
@@ -938,7 +912,7 @@ if (l_iTest != 1)
 
 
 // Ajout dans la liste des Masques
-g_wListeMasqueDouble.Append(l_wNomMasque.GetData(), l_MasqueDouble);
+g_InterfaceMasqueDouble.AjouterMasqueDouble(l_wNomMasque, l_MasqueDouble);
 g_NbMasqueDouble++;
 return;
 }
@@ -949,6 +923,6 @@ return;
 
 void MyFrame::OnTest(wxCommandEvent& WXUNUSED(event))
 {
-// Votre code
+Test();
 return;
 }
