@@ -39,6 +39,8 @@ public :
 	void OnImageBin(wxCommandEvent& event);
 	void OnInverserBin();
 	void OnDiviserBin();
+	void OnErosionBin();
+	void OnDilatationBin();
 	wxBitmap * VisualiserBin (ImageBin *l_pImageBin);
 	int AjouterImageBin(wxString l_wNomImage, ImageBin * l_pImageBin);
 	ImageBin * ChercherImageBin(wxString l_wNomImage);
