@@ -41,7 +41,7 @@ public :
 	void OnInverserDouble();
 	void OnDiviserDouble();
 	void OnImageDoubleAfficherMinMax();
-	wxBitmap * VisualiserDouble (ImageDouble *l_pImageBin);
+	wxBitmap * VisualiserDouble (ImageDouble *l_pImageDouble);
 	int AjouterImageDouble(wxString l_wNomImage, ImageDouble *l_pImageDouble);
 	ImageDouble * ChercherImageDouble(wxString l_wNomImage);
 };
